package controllers

import (
	"encoding/json"
	"eta/eta_api/cache"
	"eta/eta_api/models"
	"eta/eta_api/services/alarm_msg"
	"eta/eta_api/utils"
	"fmt"
	"github.com/beego/beego/v2/server/web"
	"github.com/sirupsen/logrus"
	"net/http"
	"net/url"
	"strings"
)

type BaseCommonController struct {
	web.Controller
}

func (c *BaseCommonController) Prepare() {
	var requestBody string
	method := c.Ctx.Input.Method()
	if method == "GET" {
		requestBody = c.Ctx.Request.RequestURI
	} else {
		requestBody, _ = url.QueryUnescape(string(c.Ctx.Input.RequestBody))
	}
	ip := c.Ctx.Input.IP()
	var reqData interface{}
	err := json.Unmarshal([]byte(requestBody), &reqData)
	if err != nil {
		utils.ApiLog.WithFields(logrus.Fields{
			"uri":         c.Ctx.Input.URI(),
			"requestBody": requestBody,
			"ip":          ip,
		}).Info("Prepare 请求详情")
	} else {
		utils.ApiLog.WithFields(logrus.Fields{
			"uri":         c.Ctx.Input.URI(),
			"requestBody": reqData,
			"ip":          ip,
		}).Info("Prepare 请求详情")
	}
}

func (c *BaseCommonController) ServeJSON(encoding ...bool) {
	var (
		hasIndent   = false
		hasEncoding = false
	)
	if web.BConfig.RunMode == web.PROD {
		hasIndent = false
	}
	if len(encoding) > 0 && encoding[0] == true {
		hasEncoding = true
	}
	if c.Data["json"] == nil {
		//go utils.SendEmail("异常提醒:"+utils.RunMode, "接口:"+"URI:"+c.Ctx.Input.URI()+";无返回值", utils.EmailSendToUsers)
		go alarm_msg.SendAlarmMsg("接口:URI:"+c.Ctx.Input.URI()+";无返回值", 3)
		return
	}
	baseRes := c.Data["json"].(*models.BaseResponse)
	if baseRes != nil && !baseRes.Success && baseRes.IsSendEmail {
		//go utils.SendEmail(utils.APPNAME+"【"+utils.RunMode+"】"+"失败提醒", "URI:"+c.Ctx.Input.URI()+" ErrMsg:"+baseRes.ErrMsg+";Msg"+baseRes.Msg, utils.EmailSendToUsers)
		go alarm_msg.SendAlarmMsg("失败提醒:URI:"+c.Ctx.Input.URI()+" ErrMsg:"+baseRes.ErrMsg+";Msg"+baseRes.Msg, 3)
	}

	//新增uuid记录
	{
		urlPath := c.Ctx.Request.URL.Path
		if _, ok := AdminOperateRecordMap[urlPath]; !ok {
			var adminId int
			var realName, params, ip, uriStr string
			ip = c.Ctx.Input.IP()
			uuid := c.Ctx.Input.Header("Uuid")
			uri := c.Ctx.Input.URI()
			userAgent := c.Ctx.Input.Header("User-Agent")

			uriStr, _ = url.PathUnescape(uri)
			if uriStr != "" {
				uri = uriStr
			}

			if c.Ctx.Input.Method() == "GET" {
				paramsJson, _ := json.Marshal(c.Ctx.Input.Params())
				params = string(paramsJson)
			} else {
				params = string(c.Ctx.Input.RequestBody)
			}
			header := c.Ctx.Request.Header
			headerJson, _ := json.Marshal(header)
			headerStr := string(headerJson)
			go cache.AdminOperateRecord(adminId, realName, uuid, uri, params, ip, userAgent, headerStr)
		}
	}

	c.JSON(c.Data["json"], hasIndent, hasEncoding)
}

func (c *BaseCommonController) JSON(data interface{}, hasIndent bool, coding bool) error {
	c.Ctx.Output.Header("Content-Type", "application/json; charset=utf-8")
	var content []byte
	var err error
	if hasIndent {
		content, err = json.MarshalIndent(data, "", "  ")
	} else {
		content, err = json.Marshal(data)
	}
	if err != nil {
		http.Error(c.Ctx.Output.Context.ResponseWriter, err.Error(), http.StatusInternalServerError)
		return err
	}
	ip := c.Ctx.Input.IP()
	params := c.Ctx.Input.Params()
	fmt.Println("params")
	fmt.Println(params)
	requestBody, _ := url.QueryUnescape(string(c.Ctx.Input.RequestBody))
	c.logUri(data, requestBody, ip)
	// 如果不是debug分支的话，那么需要加密返回
	if utils.RunMode != "debug" {
		content = utils.DesBase64Encrypt(content)
		// get请求时，不加双引号就获取不到数据，不知道什么原因，所以还是在前后加上双引号吧
		content = []byte(`"` + string(content) + `"`)
	}
	if coding {
		content = []byte(utils.StringsToJSON(string(content)))
	}
	return c.Ctx.Output.Body(content)
}

func (c *BaseCommonController) logUri(data interface{}, requestBody, ip string) {
	authorization := ""
	method := c.Ctx.Input.Method()
	uri := c.Ctx.Input.URI()
	fmt.Println("Url:", uri)
	if method != "HEAD" {
		if method == "POST" || method == "GET" {
			authorization = c.Ctx.Input.Header("authorization")
			if authorization == "" {
				authorization = c.Ctx.Input.Header("Authorization")
			}
			if authorization == "" {
				newAuthorization := c.GetString("authorization")
				if newAuthorization != `` {
					authorization = "authorization=" + newAuthorization
				} else {
					newAuthorization = c.GetString("Authorization")
					authorization = "authorization=" + newAuthorization
				}
			} else {
				if strings.Contains(authorization, ";") {
					authorization = strings.Replace(authorization, ";", "$", 1)
				}
			}
			if authorization == "" {
				strArr := strings.Split(uri, "?")
				for k, v := range strArr {
					fmt.Println(k, v)
				}
				if len(strArr) > 1 {
					authorization = strArr[1]
					authorization = strings.Replace(authorization, "Authorization", "authorization", -1)
					fmt.Println(authorization)
				}
			}
		}
	}

	var reqData interface{}
	err := json.Unmarshal([]byte(requestBody), &reqData)
	if err != nil {
		utils.ApiLog.WithFields(logrus.Fields{
			"uri":           c.Ctx.Input.URI(),
			"authorization": authorization,
			"requestBody":   requestBody,
			"responseBody":  data,
			"ip":            ip,
		}).Info("请求详情")
	} else {
		utils.ApiLog.WithFields(logrus.Fields{
			"uri":           c.Ctx.Input.URI(),
			"authorization": authorization,
			"requestBody":   reqData,
			"responseBody":  data,
			"ip":            ip,
		}).Info("请求详情")
	}
	return
}
